@@ -95,10 +95,10 @@ List shrinkTVP_cpp(arma::vec y,
 
   arma::vec kappa2_B_save;
   arma::vec lambda2_B_save;
-  if (learn_kappa2_B & (mod_type != "ridge")) {
+  if (learn_kappa2_B && (mod_type != "ridge")) {
     kappa2_B_save = arma::vec(nsave, arma::fill::zeros);
   }
-  if (learn_lambda2_B & (mod_type != "ridge")) {
+  if (learn_lambda2_B && (mod_type != "ridge")) {
     lambda2_B_save = arma::vec(nsave, arma::fill::zeros);
   }
 
@@ -107,17 +107,17 @@ List shrinkTVP_cpp(arma::vec y,
   arma::vec c_xi_save;
   arma::vec c_tau_save;
 
-  if (learn_a_xi & (mod_type != "ridge")) {
+  if (learn_a_xi && (mod_type != "ridge")) {
     a_xi_save = arma::vec(nsave, arma::fill::zeros);
   }
-  if (learn_a_tau & (mod_type != "ridge")) {
+  if (learn_a_tau && (mod_type != "ridge")) {
     a_tau_save = arma::vec(nsave, arma::fill::zeros);
   }
 
-  if (learn_c_xi & (mod_type == "triple")) {
+  if (learn_c_xi && (mod_type == "triple")) {
     c_xi_save = arma::vec(nsave, arma::fill::zeros);
   }
-  if (learn_c_tau & (mod_type == "triple")) {
+  if (learn_c_tau && (mod_type == "triple")) {
     c_tau_save = arma::vec(nsave, arma::fill::zeros);
   }
 
@@ -176,42 +176,42 @@ List shrinkTVP_cpp(arma::vec y,
 
   // Conditional objects
   double kappa2_B_samp;
-  if (learn_kappa2_B & (mod_type != "ridge")) {
+  if (learn_kappa2_B && (mod_type != "ridge")) {
     kappa2_B_samp = as<double>(starting_vals["kappa2_B_st"]);
   } else {
     kappa2_B_samp = kappa2_B;
   }
 
   double lambda2_B_samp;
-  if (learn_lambda2_B & (mod_type != "ridge")) {
+  if (learn_lambda2_B && (mod_type != "ridge")) {
     lambda2_B_samp = as<double>(starting_vals["lambda2_B_st"]);
   } else {
     lambda2_B_samp = lambda2_B;
   }
 
   double a_xi_samp;
-  if (learn_a_xi & (mod_type != "ridge")) {
+  if (learn_a_xi && (mod_type != "ridge")) {
     a_xi_samp = as<double>(starting_vals["a_xi_st"]);
   } else {
     a_xi_samp = a_xi;
   }
 
   double a_tau_samp;
-  if (learn_a_tau & (mod_type != "ridge")) {
+  if (learn_a_tau && (mod_type != "ridge")) {
     a_tau_samp = as<double>(starting_vals["a_tau_st"]);
   } else {
     a_tau_samp = a_tau;
   }
 
   double c_xi_samp;
-  if (learn_c_xi & (mod_type == "triple")) {
+  if (learn_c_xi && (mod_type == "triple")) {
     c_xi_samp = as<double>(starting_vals["c_xi_st"]);
   } else {
     c_xi_samp = c_xi;
   }
 
   double c_tau_samp;
-  if (learn_c_tau & (mod_type == "triple")) {
+  if (learn_c_tau && (mod_type == "triple")) {
     c_tau_samp = as<double>(starting_vals["c_tau_st"]);
   } else {
     c_tau_samp = c_tau;
@@ -259,7 +259,7 @@ List shrinkTVP_cpp(arma::vec y,
 
 
   arma::vec sigma2_samp;
-  double C0_samp;
+  double C0_samp = 1;
   arma::vec sv_para(3);
   if (sv == true) {
     sigma2_samp = as<arma::vec>(starting_vals["sigma2_st"]);
@@ -583,26 +583,26 @@ List shrinkTVP_cpp(arma::vec y,
           lambda2_save.col((post_j-1)/nthin) = lambda2_til_samp;
         }
 
-        if (learn_kappa2_B & (mod_type != "ridge")) {
+        if (learn_kappa2_B && (mod_type != "ridge")) {
           kappa2_B_save((post_j-1)/nthin) = kappa2_B_samp;
         }
-        if (learn_lambda2_B & (mod_type != "ridge")) {
+        if (learn_lambda2_B && (mod_type != "ridge")) {
           lambda2_B_save((post_j-1)/nthin) = lambda2_B_samp;
         }
 
-        if (learn_a_xi & (mod_type != "ridge")) {
+        if (learn_a_xi && (mod_type != "ridge")) {
           a_xi_save((post_j-1)/nthin) = a_xi_samp;
         }
 
-        if (learn_a_tau & (mod_type != "ridge")) {
+        if (learn_a_tau && (mod_type != "ridge")) {
           a_tau_save((post_j-1)/nthin) = a_tau_samp;
         }
 
-        if (learn_c_xi & (mod_type == "triple")) {
+        if (learn_c_xi && (mod_type == "triple")) {
           c_xi_save((post_j-1)/nthin) = c_xi_samp;
         }
 
-        if (learn_c_tau & (mod_type == "triple")) {
+        if (learn_c_tau && (mod_type == "triple")) {
           c_tau_save((post_j-1)/nthin) = c_tau_samp;
         }
 
